#[non_exhaustive]pub enum TokenizerError {
UnknownToken(String),
Io(Error),
MalformedFile(String),
}Expand description
Errors that can occur while tokenizing text or loading a tokenizer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownToken(String)
A sub-word produced during tokenization is not present in the
vocabulary, and no <unk> / [UNK] fallback id was configured.
Io(Error)
An I/O error while loading a vocabulary or merge file (std builds only).
MalformedFile(String)
A line in a vocabulary or merge file could not be parsed.